@@ -7,7 +7,7 @@ use strict;
 use integer;    # vroom vroom!
 use Carp ();
 
-our $VERSION = '4.902'; # TRIAL VERSION from OurPkgVersion
+our $VERSION = '4.903'; # TRIAL VERSION from OurPkgVersion
 
 #---------------------------------------------------------------------------
 # Make a 'DEBUG' constant...
@@ -1683,8 +1683,8 @@ HTML::TreeBuilder - Parser that builds a HTML syntax tree
 =head1 VERSION
 
 B<This is a development release for testing purposes only.>
-This document describes version 4.902 of
-HTML::TreeBuilder, released June 6, 2012
+This document describes version 4.903 of
+HTML::TreeBuilder, released June 8, 2012
 as part of HTML-Tree.
 
 =head1 SYNOPSIS
@@ -1887,7 +1887,7 @@ This "shortcut" constructor merely combines constructing a new object
 it.  Returns the new object.  Note that this provides no way of
 setting any parse options like C<store_comments> (for that, call C<new>, and
 then set options, before calling C<parse_file>).  See the notes (below)
-on parameters to C<parse_file>.
+on parameters to L</parse_file>.
 
 =head2 new_from_content
 
@@ -1939,6 +1939,24 @@ IO::File, IO::Socket) or the like.
 I think you should check that a given file exists I<before> calling
 C<< $root->parse_file($filespec) >>.]
 
+When you pass a filename to C<parse_file>, HTML::Parser opens it in
+binary mode, which means it's interpreted as Latin-1 (ISO-8859-1).  If
+the file is in another encoding, like UTF-8 or UTF-16, this will not
+do the right thing.
+
+One solution is to open the file yourself using the proper
+C<:encoding> layer, and pass the filehandle to C<parse_file>.  You can
+automate this process by using L<IO::HTML/html_file>, which will use
+the HTML5 encoding sniffing algorithm to automatically determine the
+proper C<:encoding> layer and apply it.
+
+In the next major release of HTML-Tree, I plan to have it use IO::HTML
+automatically.  If you really want your file opened in binary mode,
+you should open it yourself and pass the filehandle to C<parse_file>.
+
+The return value is C<undef> if there's an error opening the file.  In
+that case, the error will be in C<$!>.
+
 =head2 parse
 
   $root->parse(...)
